@@ -46,10 +46,7 @@ impl OneShotMdnsResolver {
     }
 
     /// Send a query packet and returns the first response
-    pub fn query_packet<'a>(
-        &self,
-        packet: PacketBuf,
-    ) -> Result<Option<PacketBuf>, SimpleMdnsError> {
+    pub fn query_packet(&self, packet: PacketBuf) -> Result<Option<PacketBuf>, SimpleMdnsError> {
         // let mut socket = create_udp_socket(self.enable_loopback)?;
         // send_packet_to_multicast_socket(&socket, &packet)?;
         self.sender_socket
@@ -62,7 +59,7 @@ impl OneShotMdnsResolver {
         &self,
         service_name: &str,
     ) -> Result<Option<std::net::IpAddr>, SimpleMdnsError> {
-        let mut packet = PacketBuf::new(PacketHeader::new_query(rand::random(), false));
+        let mut packet = PacketBuf::new(PacketHeader::new_query(rand::random(), false), true);
         let service_name = Name::new(service_name)?;
         packet.add_question(&Question::new(
             service_name.clone(),
@@ -94,7 +91,7 @@ impl OneShotMdnsResolver {
         &self,
         service_name: &str,
     ) -> Result<Option<std::net::SocketAddr>, SimpleMdnsError> {
-        let mut packet = PacketBuf::new(PacketHeader::new_query(rand::random(), false));
+        let mut packet = PacketBuf::new(PacketHeader::new_query(rand::random(), false), true);
         let parsed_name_service = Name::new(service_name)?;
         packet.add_question(&Question::new(
             parsed_name_service.clone(),
