@@ -164,7 +164,8 @@ impl ServiceDiscovery {
                 match next_expiration {
                     Some(expiration) => {
                         if expiration.refresh_at < now {
-                            let mut packet = PacketBuf::new(PacketHeader::new_query(0, false));
+                            let mut packet =
+                                PacketBuf::new(PacketHeader::new_query(0, false), true);
                             packet
                                 .add_question(&Question::new(
                                     service_name.clone(),
@@ -195,7 +196,7 @@ impl ServiceDiscovery {
 
     fn advertise_service(&self) {
         log::info!("Advertising service");
-        let mut packet = PacketBuf::new(PacketHeader::new_reply(0, OPCODE::StandardQuery));
+        let mut packet = PacketBuf::new(PacketHeader::new_reply(0, OPCODE::StandardQuery), true);
         {
             let resource_manager = self.resource_manager.read().unwrap();
 
@@ -241,7 +242,7 @@ impl ServiceDiscovery {
         let service_name = self.service_name.clone();
 
         log::info!("probing service instances");
-        let mut packet = PacketBuf::new(PacketHeader::new_query(0, false));
+        let mut packet = PacketBuf::new(PacketHeader::new_query(0, false), true);
         packet
             .add_question(&Question::new(service_name, QTYPE::SRV, QCLASS::IN, false))
             .unwrap();
@@ -262,7 +263,7 @@ impl ServiceDiscovery {
         let sender_socket = sender_socket(&super::MULTICAST_IPV4_SOCKET).unwrap();
         let receiver_socket = match join_multicast(&super::MULTICAST_IPV4_SOCKET) {
             Ok(socket) => {
-                if let Err(_) = socket.set_read_timeout(None) {
+                if socket.set_read_timeout(None).is_err() {
                     log::error!("Can't set socket timeout, will poll for packets");
                 }
 
@@ -333,7 +334,7 @@ fn add_response_to_known_instances(
     known_instances: &RwLock<HashMap<SocketAddr, ExpirationTimes>>,
     owned_resources: &ResourceRecordManager,
 ) {
-    if let Ok(packet) = Packet::parse(&recv_buffer) {
+    if let Ok(packet) = Packet::parse(recv_buffer) {
         log::debug!("received packet");
         let mut known_instances = known_instances.write().unwrap();
         let srvs = packet
